@@ -1303,7 +1303,7 @@ class MultipartParser(BaseParser):
                     # Search forward until we either hit the end of our buffer,
                     # or reach a character that's in our boundary.
                     i += boundary_end
-                    while i < data_length and data[i] not in boundary_chars:
+                    while i < data_length - 1 and data[i] not in boundary_chars:
                         i += boundary_length
 
                     # Reset i back the length of our boundary, which is the
@@ -1562,7 +1562,7 @@ class FormParser(object):
                 f = None
 
             def on_start():
-                vars.f = FileClass(file_name, None)
+                vars.f = FileClass(file_name, None, config=self.config)
 
             def on_data(data, start, end):
                 vars.f.write(data[start:end])
@@ -1699,7 +1699,7 @@ class FormParser(object):
                 if file_name is None:
                     vars.f = FieldClass(field_name)
                 else:
-                    vars.f = FileClass(file_name, field_name)
+                    vars.f = FileClass(file_name, field_name, config=self.config)
                     vars.is_file = True
 
                 # Parse the given Content-Transfer-Encoding to determine what
